OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Favor de aguardar hasta que termine",
    "Migration started …" : "La migración ha comenzado ...",
    "Saved" : "Guardado",
    "Not saved" : "No guardado",
    "Sending…" : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Se presentó un error. Favor de cargar un certificado PEM con codificación ASCII",
    "Valid until {date}" : "Válido hasta {date}",
    "Delete" : "Borrar",
    "Local" : "Local",
    "Private" : "Privado",
    "Only visible to local users" : "Visible sólo para usuarios locales",
    "Only visible to you" : "Sólo visible para usted",
    "Contacts" : "Contactos",
    "Visible to local users and to trusted servers" : "Visible para usuarios locales y para servidores de confianza",
    "Public" : "Público",
    "Will be synced to a global and public address book" : "Será sincronizado a una libreta de direcciones global y pública",
    "Verify" : "Verificar",
    "Verifying …" : "Verificando ...",
    "Unable to change password" : "No fue posible cambiar la contraseña",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña aceptable",
    "Good password" : "Buena contraseña",
    "Strong password" : "Contraseña fuerte",
    "Select a profile picture" : "Seleccionar una imagen de perfil",
    "Groups" : "Grupos",
    "{actor} changed your password" : "{actor} ha cambiado su contraseña",
    "You changed your password" : "Usted ha cambiado su contraseña",
    "Your password was reset by an administrator" : "Su contraseña ha sido restablecida por un adminsitrador",
    "{actor} changed your email address" : "{actor} ha cambiado su dirección de correo electrónico",
    "You changed your email address" : "Usted ha cambiado su dirección de correo electrónico",
    "Your email address was changed by an administrator" : "Su dirección de correo electrónico ha sido cambiada por un administrador",
    "Security" : "Seguridad",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ha iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autienticación de dos-factores ha fallado (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Su <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
    "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
    "Couldn't update app." : "No fue posible actualizar la aplicación.",
    "Wrong password" : "Contraseña incorrecta",
    "No user supplied" : "No se proporcionó un usuario",
    "Authentication error" : "Error de autenticación",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Favor de proporcionar una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
    "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Favor de verificarla e inténtelo de nuevo.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Instalando y actualizando aplicaciones por la tienda de aplicaciones o Compartido la Nube Federada",
    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
    "Invalid SMTP password." : "Constraseña SMTP inválida. ",
    "Email setting test" : "Prueba de ajustes de correo",
    "Well done, %s!" : "¡Bien hecho, %s!",
    "If you received this email, the email configuration seems to be correct." : "Si usted ha recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
    "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Favor de verficiar la bitácora de su servidor de correo",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Favor de revisar sus configuraciones (Error: %s)",
    "You need to set your user email before being able to send test emails." : "Requiere establecer su correo electrónico andes de poder enviar correos electrónicos de prueba. ",
    "Invalid mail address" : "Dirección de correo inválida",
    "Settings saved" : "Se han guardado las configuraciones ",
    "Unable to change full name" : "No fue posible cambiar el nombre completo",
    "Unable to change email address" : "No fue posible cambiar la dirección de correo electrónico",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Para poder verificar su cuenta de Twitter, publique el siguiente tweet en Twitter (favor de asegurarse de publicar sin ninguna línea en blanco):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Para poder verficiar si sitio Web, agrege el siguiente contendio a su web-root en '.well-known/CloudIdVerificationCode.txt' (favor de asegurarse de que el texto completo este en una sóla línea):",
    "%1$s changed your password on %2$s." : "%1$s cambió su contraseña el %2$s.",
    "Your password on %s was changed." : "Su contraseña de %s fue cambiada. ",
    "Your password on %s was reset by an administrator." : "Su contraseña de %s fue restablecida por un administrador.",
    "Password for %1$s changed on %2$s" : "La contraseña para %1$s fue cambiada el %2$s",
    "Password changed for %s" : "La contraseña fue cambiada para %s",
    "If you did not request this, please contact an administrator." : "Si no lo solicitó, favor de contactar a un administrador. ",
    "Your email address on %s was changed." : "Su dirección de correo electrónico en %s fue cambiada. ",
    "Your email address on %s was changed by an administrator." : "Su dirección de correo electrónico en %s fue cambiada por un adminsitrador. ",
    "Email address for %1$s changed on %2$s" : "La dirección de correo electrónico para %1$s fue cambiada el %2$s",
    "Email address changed for %s" : "La dirección de correo electrónico fue cambiada para %s",
    "The new email address is %s" : "La nueva dirección de correo electrónico es %s",
    "Your %s account was created" : "Su %s cuenta ha sido creada",
    "Welcome aboard" : "Bienvenido a bordo",
    "Welcome aboard %s" : "Bienvenido a bordo %s",
    "Your username is: %s" : "Su nombre de usuario es: %s",
    "Set your password" : "Establezca su contraseña",
    "Go to %s" : "Ir a %s",
    "Install Client" : "Instalar el cliente",
    "Unlimited" : "Ilimitado",
    "Limit to groups" : "Limitar a grupos",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Las aplicaciones oficiales son desarrolladas por y dentro de la comunidad. Ofrecen una funcionalidad centralizada y se encuentran listas para ser usadas en producción. ",
    "Official" : "Oficial",
    "Remove" : "Eliminar",
    "Disable" : "Deshabilitar",
    "All" : "Todos",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
    "View in store" : "Ver en la tienda",
    "Visit website" : "Visite el sitio web",
    "Report a bug" : "Reporte un tema",
    "User documentation" : "Documentación del usuario",
    "Admin documentation" : "Documentación del administrador",
    "Developer documentation" : "Documentación del desarrollador",
    "No apps found for your version" : "No se encontraron aplicaciones para su versión",
    "Enable all" : "Habilitar todo",
    "Enable" : "Habilitar",
    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
    "Allow filesystem access" : "Permitir acceso al sistema de archivos",
    "Revoke" : "Revocar",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome para Android",
    "Sync client - {os}" : "Sync client - {os}",
    "This session" : "Esta sesión",
    "Device" : "Dispositivo",
    "Last activity" : "Última actividad",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en su cuenta. ",
    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
    "App name" : "Nombre de la aplicación",
    "Create new app password" : "Crear una nueva contraseña de aplicación",
    "Use the credentials below to configure your app or device." : "Use las siguientes credenciales para configurar su aplicación o dispositivo. ",
    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Done" : "Terminado",
    "Copied!" : "¡Credenciales!",
    "Copy" : "Copiar",
    "New password" : "Nueva contraseña",
    "Email" : "Correo electrónico",
    "Group admin for" : "Administrador del grupo para",
    "Quota" : "Cuota",
    "Language" : "Idioma",
    "Storage location" : "Úbicación del almacenamiento",
    "User backend" : "Backend del usuario",
    "Last login" : "Último inicio de sesión",
    "Default quota" : "Cuota predeterminada",
    "Your apps" : "Sus aplicaciones",
    "Disabled apps" : "Aplicaciones deshabilitadas",
    "App bundles" : "Paquetes de aplicacion",
    "Show last login" : "Mostrar último inicio de sesión",
    "Show user backend" : "Mostrar backend del usuario",
    "Admins" : "Administradores",
    "Everyone" : "Todos",
    "Add group" : "Agregar grupo",
    "SSL Root Certificates" : "Certificado SSL Raíz",
    "Common Name" : "Nombre común",
    "Valid until" : "Válido hasta",
    "Issued By" : "Levantado Por",
    "Valid until %s" : "Válido hasta %s",
    "Import root certificate" : "Importar certificado raíz",
    "Administrator documentation" : "Documentación de adminsitrador",
    "Forum" : "Foro",
    "None" : "Ninguno",
    "Login" : "Inicio de sesión",
    "Plain" : "Plano",
    "NT LAN Manager" : "Administrador de LAN NT",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor de correo electrónico",
    "Open documentation" : "Abrir documentación",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
    "Send mode" : "Modo de envío",
    "Encryption" : "Encripción",
    "From address" : "De la dirección",
    "mail" : "correo",
    "Authentication method" : "Método de autenticación",
    "Authentication required" : "Autenticación requerida",
    "Server address" : "Dirección del servidor",
    "Port" : "Puerto",
    "Credentials" : "Credenciales",
    "SMTP Username" : "nombre de usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Test email settings" : "Probar las configuraciones de correo electrónico",
    "Send email" : "Enviar correo electrónico",
    "Security & setup warnings" : "Advertencias de seguridad y configuración",
    "All checks passed." : "Pasaron todas las verificaciones. ",
    "Version" : "Versión",
    "Server-side encryption" : "Encripción del lado del servidor",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que sólo habilítelo si es necesario. ",
    "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
    "Please read carefully before activating server-side encryption: " : "Favor de leer detenidamente antes de activar la encripción del lado de servidor:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Favor de consultar la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
    "Be aware that encryption always increases the file size." : "Favor de considerar que la encripción siempre aumenta el tamaño de los archivos. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de sus datos, en caso de tener encripción asegúrese de respaldar las llaves de encripción junto con sus datos. ",
    "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente desea habilitar la encripción?",
    "Enable encryption" : "Habilitar encripción",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, favor de habilitar un módulo de encripción en el menú de la aplicación. ",
    "Select default encryption module:" : "Seleccionar modulo de encripción predeterminado:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Usted necesita migrar sus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Favor de habilitar el \"Módulo de encripción predeterminado\" y ejecute el comando 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Usted necesita migar sus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
    "Start migration" : "Comenzar migración",
    "Background jobs" : "Trabajos en segundo plano",
    "Last job ran %s." : "El último trabajo corrió %s.",
    "Last job execution ran %s. Something seems wrong." : "La última ejecución del trabajo corrió %s. Algo parece estar mal. ",
    "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un desempeño ideal, es importante configurar los trabajos de fondo correctametne. Para instancias más grandes 'Cron' es el ajuste recomendado. Favor de consultar la documentación para más información. ",
    "Execute one task with each page loaded" : "Ejecutar una tarea con cada página cargada",
    "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario del sistema \"%s\".",
    "Sharing" : "Compartiendo",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, usted puede hacer ajustes finos al comportamiento de compartir. Favor de consultar la documentación para más información. ",
    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
    "Allow users to share via link" : "Permitir a los usuarios compartir mediante links",
    "Allow public uploads" : "Permitir cargas públicas",
    "Always ask for a password" : "Siempre pedir una contraseña",
    "Enforce password protection" : "Forzar protección de contraseñas",
    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
    "Expire after " : "Expirar después de",
    "days" : "días",
    "Enforce expiration date" : "Forzar fecha de expiración",
    "Allow resharing" : "Permitir volver a compartir",
    "Allow sharing with groups" : "Permitir compartir con grupos",
    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
    "Exclude groups from sharing" : "Evitar que los grupos compartan",
    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos áun podrán recibir elementos compartidos, pero no los podrán iniciar.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Mostrar el texto de exención de responsabilidad legal en la página de carga de links públicos. (Sólo se muestra cuando la lista de archivos está oculta.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de el link público cuando la lista de archivos esté oculta. ",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
    "Profile picture" : "Foto de perfil",
    "Upload new" : "Cargar nuevo",
    "Select from Files" : "Seleccionar desde Archivos",
    "Remove image" : "Eliminar imagen",
    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
    "Picture provided by original account" : "Imagen proporcionadoa por la cuenta original ",
    "Cancel" : "Cancelar",
    "Choose as profile picture" : "Seleccionar como foto del perfil",
    "Full name" : "Nombre completo",
    "No display name set" : "No se ha establecido el nombre a desplegar",
    "Your email address" : "Su dirección de correo electrónico",
    "No email address set" : "No se ha establecido la dirección de correo electrónico",
    "For password reset and notifications" : "Para reestablecer contraseña y notificaciones",
    "Phone number" : "Número de teléfono",
    "Your phone number" : "Su número telefónico",
    "Address" : "Dirección",
    "Your postal address" : "Su dirección postal",
    "Website" : "Sitio web",
    "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
    "Link https://…" : "Link https:// ...",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Cuenta de twitter @...",
    "Help translate" : "Ayude a traducir",
    "Current password" : "Contraseña actual",
    "Change password" : "Cambiar contraseña",
    "Store credentials" : "Almacenar credenciales",
    "Use system cron service to call the cron.php file every 15 minutes." : "Usar el servicio cron del sistema para llamar al archivo cron.php cada 15 minutos. "
},
"nplurals=2; plural=(n != 1);");
